@@ -36,12 +36,20 @@
 #	endif
 #endif
 
+#ifdef PHP_HTTP_HAVE_OPENSSL
+#	include <openssl/ssl.h>
+#endif
+#ifdef PHP_HTTP_HAVE_GNUTLS
+#	include <gnutls.h>
+#endif
+
 typedef struct php_http_client_curl {
 	CURLM *handle;
 
 	int unfinished;  /* int because of curl_multi_perform() */
 
 #if PHP_HTTP_HAVE_EVENT
+	struct event_base *evbase;
 	struct event *timeout;
 	unsigned useevents:1;
 #endif
@@ -91,6 +99,7 @@ typedef struct php_http_client_curl_handler {
 typedef struct php_http_curle_storage {
 	char *url;
 	char *cookiestore;
+	CURLcode errorcode;
 	char errorbuffer[0x100];
 } php_http_curle_storage_t;
 
@@ -187,7 +196,11 @@ static size_t php_http_curle_read_callback(void *data, size_t len, size_t n, voi
 	return 0;
 }
 
+#if PHP_HTTP_CURL_VERSION(7,32,0)
+static int php_http_curle_xferinfo_callback(void *ctx, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow)
+#else
 static int php_http_curle_progress_callback(void *ctx, double dltotal, double dlnow, double ultotal, double ulnow)
+#endif
 {
 	php_http_client_curl_handler_t *h = ctx;
 	zend_bool update = 0;
@@ -474,6 +487,86 @@ static STATUS php_http_curle_get_info(CURL *ch, HashTable *info)
 
 	/* END::CURLINFO */
 
+#if PHP_HTTP_CURL_VERSION(7,34,0)
+	{
+		zval *ti_array;
+		struct curl_tlssessioninfo *ti;
+
+		if (CURLE_OK == curl_easy_getinfo(ch, CURLINFO_TLS_SESSION, &ti)) {
+			const char *backend;
+
+			MAKE_STD_ZVAL(subarray);
+			ZVAL_NULL(subarray);
+			MAKE_STD_ZVAL(ti_array);
+			array_init(ti_array);
+
+			switch (ti->backend) {
+			case CURLSSLBACKEND_NONE:
+				backend = "none";
+				break;
+			case CURLSSLBACKEND_OPENSSL:
+				backend = "openssl";
+#ifdef PHP_HTTP_HAVE_OPENSSL
+				{
+					SSL_CTX *ctx = ti->internals;
+
+					array_init(subarray);
+					add_assoc_long_ex(subarray, ZEND_STRS("number"), SSL_CTX_sess_number(ctx));
+					add_assoc_long_ex(subarray, ZEND_STRS("connect"), SSL_CTX_sess_connect(ctx));
+					add_assoc_long_ex(subarray, ZEND_STRS("connect_good"), SSL_CTX_sess_connect_good(ctx));
+					add_assoc_long_ex(subarray, ZEND_STRS("connect_renegotiate"), SSL_CTX_sess_connect_renegotiate(ctx));
+					add_assoc_long_ex(subarray, ZEND_STRS("hits"), SSL_CTX_sess_hits(ctx));
+					add_assoc_long_ex(subarray, ZEND_STRS("cache_full"), SSL_CTX_sess_cache_full(ctx));
+				}
+#endif
+				break;
+			case CURLSSLBACKEND_GNUTLS:
+				backend = "gnutls";
+#ifdef PHP_HTTP_HAVE_GNUTLS
+				{
+					gnutls_session_t sess = ti->internals;
+					char *desc;
+
+					array_init(subarray);
+					if ((desc = gnutls_session_get_desc(sess))) {
+						add_assoc_string_ex(subarray, ZEND_STRS("desc"), desc, 1);
+						gnutls_free(desc);
+					}
+					add_assoc_bool_ex(subarray, ZEND_STRS("resumed"), gnutls_session_is_resumed(sess));
+				}
+#endif
+				break;
+			case CURLSSLBACKEND_NSS:
+				backend = "nss";
+				break;
+			case CURLSSLBACKEND_QSOSSL:
+				backend = "qsossl";
+				break;
+			case CURLSSLBACKEND_GSKIT:
+				backend = "gskit";
+				break;
+			case CURLSSLBACKEND_POLARSSL:
+				backend = "polarssl";
+				break;
+			case CURLSSLBACKEND_CYASSL:
+				backend = "cyassl";
+				break;
+			case CURLSSLBACKEND_SCHANNEL:
+				backend = "schannel";
+				break;
+			case CURLSSLBACKEND_DARWINSSL:
+				backend = "darwinssl";
+				break;
+			default:
+				backend = "unknown";
+			}
+			add_assoc_string_ex(ti_array, ZEND_STRS("backend"), estrdup(backend), 0);
+			add_assoc_zval_ex(ti_array, ZEND_STRS("internals"), subarray);
+			add_assoc_zval_ex(&array, "tls_session", sizeof("tls_session"), ti_array);
+		}
+	}
+#endif
+
 #if PHP_HTTP_CURL_VERSION(7,19,1) && defined(PHP_HTTP_HAVE_OPENSSL)
 	{
 		int i;
@@ -507,7 +600,12 @@ static STATUS php_http_curle_get_info(CURL *ch, HashTable *info)
 		}
 	}
 #endif
-	add_assoc_string_ex(&array, "error", sizeof("error"), php_http_curle_get_storage(ch)->errorbuffer, 1);
+	{
+		php_http_curle_storage_t *st = php_http_curle_get_storage(ch);
+
+		add_assoc_long_ex(&array, "curlcode", sizeof("curlcode"), st->errorcode);
+		add_assoc_string_ex(&array, "error", sizeof("error"), st->errorbuffer, 1);
+	}
 
 	return SUCCESS;
 }
@@ -530,7 +628,7 @@ static void php_http_curlm_responsehandler(php_http_client_t *context)
 		if (msg && CURLMSG_DONE == msg->msg) {
 			if (CURLE_OK != msg->data.result) {
 				php_http_curle_storage_t *st = php_http_curle_get_storage(msg->easy_handle);
-				php_error_docref(NULL TSRMLS_CC, E_WARNING, "%s; %s (%s)", curl_easy_strerror(msg->data.result), STR_PTR(st->errorbuffer), STR_PTR(st->url));
+				php_error_docref(NULL TSRMLS_CC, E_WARNING, "%s; %s (%s)", curl_easy_strerror(st->errorcode = msg->data.result), STR_PTR(st->errorbuffer), STR_PTR(st->url));
 			}
 
 			if ((enqueue = php_http_client_enqueued(context, msg->easy_handle, compare_queue))) {
@@ -661,7 +759,7 @@ static int php_http_curlm_socket_callback(CURL *easy, curl_socket_t sock, int ac
 				return -1;
 		}
 
-		event_assign(&ev->evnt, PHP_HTTP_G->curl.event_base, sock, events, php_http_curlm_event_callback, context);
+		event_assign(&ev->evnt, curl->evbase, sock, events, php_http_curlm_event_callback, context);
 		event_add(&ev->evnt, NULL);
 	}
 
@@ -682,10 +780,9 @@ static void php_http_curlm_timer_callback(CURLM *multi, long timeout_ms, void *t
 			php_http_curlm_timeout_callback(CURL_SOCKET_TIMEOUT, /*EV_READ|EV_WRITE*/0, context);
 		} else if (timeout_ms > 0 || !event_initialized(curl->timeout) || !event_pending(curl->timeout, EV_TIMEOUT, NULL)) {
 			struct timeval timeout;
-			TSRMLS_FETCH_FROM_CTX(context->ts);
 
 			if (!event_initialized(curl->timeout)) {
-				event_assign(curl->timeout, PHP_HTTP_G->curl.event_base, CURL_SOCKET_TIMEOUT, 0, php_http_curlm_timeout_callback, context);
+				event_assign(curl->timeout, curl->evbase, CURL_SOCKET_TIMEOUT, 0, php_http_curlm_timeout_callback, context);
 			} else if (event_pending(curl->timeout, EV_TIMEOUT, NULL)) {
 				event_del(curl->timeout);
 			}
@@ -704,9 +801,9 @@ static void php_http_curlm_timer_callback(CURLM *multi, long timeout_ms, void *t
 
 static php_http_options_t php_http_curle_options;
 
-#define PHP_HTTP_CURLE_OPTION_CHECK_STRLEN	0x0001
-#define PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR	0x0002
-#define PHP_HTTP_CURLE_OPTION_TRANSFORM_MS	0x0004
+#define PHP_HTTP_CURLE_OPTION_CHECK_STRLEN		0x0001
+#define PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR		0x0002
+#define PHP_HTTP_CURLE_OPTION_TRANSFORM_MS		0x0004
 
 static STATUS php_http_curle_option_set_ssl_verifyhost(php_http_option_t *opt, zval *val, void *userdata)
 {
@@ -723,19 +820,20 @@ static STATUS php_http_curle_option_set_cookiestore(php_http_option_t *opt, zval
 {
 	php_http_client_curl_handler_t *curl = userdata;
 	CURL *ch = curl->handle;
+	php_http_curle_storage_t *storage = php_http_curle_get_storage(curl->handle);
 
-	if (val) {
-		php_http_curle_storage_t *storage = php_http_curle_get_storage(curl->handle);
-
-		if (storage->cookiestore) {
-			pefree(storage->cookiestore, 1);
-		}
+	if (storage->cookiestore) {
+		pefree(storage->cookiestore, 1);
+	}
+	if (val && Z_STRLEN_P(val)) {
 		storage->cookiestore = pestrndup(Z_STRVAL_P(val), Z_STRLEN_P(val), 1);
-		if (	CURLE_OK != curl_easy_setopt(ch, CURLOPT_COOKIEFILE, storage->cookiestore)
-			||	CURLE_OK != curl_easy_setopt(ch, CURLOPT_COOKIEJAR, storage->cookiestore)
-		) {
-			return FAILURE;
-		}
+	} else {
+		storage->cookiestore = NULL;
+	}
+	if (	CURLE_OK != curl_easy_setopt(ch, CURLOPT_COOKIEFILE, storage->cookiestore)
+		||	CURLE_OK != curl_easy_setopt(ch, CURLOPT_COOKIEJAR, storage->cookiestore)
+	) {
+		return FAILURE;
 	}
 	return SUCCESS;
 }
@@ -778,6 +876,11 @@ static STATUS php_http_curle_option_set_cookies(php_http_option_t *opt, zval *va
 				}
 			}
 		}
+	} else {
+		php_http_buffer_reset(&curl->options.cookies);
+		if (CURLE_OK != curl_easy_setopt(ch, CURLOPT_COOKIE, NULL)) {
+			return FAILURE;
+		}
 	}
 	return SUCCESS;
 }
@@ -833,13 +936,15 @@ static STATUS php_http_curle_option_set_etag(php_http_option_t *opt, zval *val,
 {
 	php_http_client_curl_handler_t *curl = userdata;
 	php_http_buffer_t header;
-	zend_bool is_quoted = !((Z_STRVAL_P(val)[0] != '"') || (Z_STRVAL_P(val)[Z_STRLEN_P(val)-1] != '"'));
 
-	php_http_buffer_init(&header);
-	php_http_buffer_appendf(&header, is_quoted?"%s: %s":"%s: \"%s\"", curl->options.range_request?"If-Match":"If-None-Match", Z_STRVAL_P(val));
-	php_http_buffer_fix(&header);
-	curl->options.headers = curl_slist_append(curl->options.headers, header.data);
-	php_http_buffer_dtor(&header);
+	if (Z_STRLEN_P(val)) {
+		zend_bool is_quoted = !((Z_STRVAL_P(val)[0] != '"') || (Z_STRVAL_P(val)[Z_STRLEN_P(val)-1] != '"'));
+		php_http_buffer_init(&header);
+		php_http_buffer_appendf(&header, is_quoted?"%s: %s":"%s: \"%s\"", curl->options.range_request?"If-Match":"If-None-Match", Z_STRVAL_P(val));
+		php_http_buffer_fix(&header);
+		curl->options.headers = curl_slist_append(curl->options.headers, header.data);
+		php_http_buffer_dtor(&header);
+	}
 	return SUCCESS;
 }
 
@@ -1029,10 +1134,23 @@ static void php_http_curle_options_init(php_http_options_t *registry TSRMLS_DC)
 		opt->setter = php_http_curle_option_set_resolve;
 	}
 #endif
-#if PHP_HTTP_CURL_VERSION(7,24,0)
+#if PHP_HTTP_HAVE_ARES
+# if PHP_HTTP_CURL_VERSION(7,24,0)
 	if ((opt = php_http_option_register(registry, ZEND_STRL("dns_servers"), CURLOPT_DNS_SERVERS, IS_STRING))) {
 		opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
 	}
+# endif
+# if PHP_HTTP_CURL_VERSION(7,33,0)
+	if ((opt = php_http_option_register(registry, ZEND_STRL("dns_interface"), CURLOPT_DNS_INTERFACE, IS_STRING))) {
+		opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+	}
+	if ((opt = php_http_option_register(registry, ZEND_STRL("dns_local_ip4"), CURLOPT_DNS_LOCAL_IP4, IS_STRING))) {
+		opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+	}
+	if ((opt = php_http_option_register(registry, ZEND_STRL("dns_local_ip6"), CURLOPT_DNS_LOCAL_IP6, IS_STRING))) {
+		opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+	}
+# endif
 #endif
 
 	/* limits */
@@ -1167,8 +1285,15 @@ static void php_http_curle_options_init(php_http_options_t *registry TSRMLS_DC)
 		opt->flags |= PHP_HTTP_CURLE_OPTION_TRANSFORM_MS;
 		Z_DVAL(opt->defval) = 3;
 	}
+#if PHP_HTTP_CURL_VERSION(7,36,0)
+	if ((opt = php_http_option_register(registry, ZEND_STRL("expect_100_timeout"), CURLOPT_EXPECT_100_TIMEOUT_MS, IS_DOUBLE))) {
+		opt->flags |= PHP_HTTP_CURLE_OPTION_TRANSFORM_MS;
+		Z_DVAL(opt->defval) = 1;
+	}
+#endif
 
 	/* tcp */
+	php_http_option_register(registry, ZEND_STRL("tcp_nodelay"), CURLOPT_TCP_NODELAY, IS_BOOL);
 #if PHP_HTTP_CURL_VERSION(7,25,0)
 	php_http_option_register(registry, ZEND_STRL("tcp_keepalive"), CURLOPT_TCP_KEEPALIVE, IS_BOOL);
 	if ((opt = php_http_option_register(registry, ZEND_STRL("tcp_keepidle"), CURLOPT_TCP_KEEPIDLE, IS_LONG))) {
@@ -1187,14 +1312,21 @@ static void php_http_curle_options_init(php_http_options_t *registry TSRMLS_DC)
 			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
 			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR;
 		}
-		php_http_option_register(registry, ZEND_STRL("certtype"), CURLOPT_SSLCERTTYPE, IS_STRING);
-
+		if ((opt = php_http_option_register(registry, ZEND_STRL("certtype"), CURLOPT_SSLCERTTYPE, IS_STRING))) {
+			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+			ZVAL_STRING(&opt->defval, "PEM", 0);
+		}
 		if ((opt = php_http_option_register(registry, ZEND_STRL("key"), CURLOPT_SSLKEY, IS_STRING))) {
 			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
 			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR;
 		}
-		php_http_option_register(registry, ZEND_STRL("keytype"), CURLOPT_SSLKEYTYPE, IS_STRING);
-		php_http_option_register(registry, ZEND_STRL("keypasswd"), CURLOPT_SSLKEYPASSWD, IS_STRING);
+		if ((opt = php_http_option_register(registry, ZEND_STRL("keytype"), CURLOPT_SSLKEYTYPE, IS_STRING))) {
+			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+			ZVAL_STRING(&opt->defval, "PEM", 0);
+		}
+		if ((opt = php_http_option_register(registry, ZEND_STRL("keypasswd"), CURLOPT_SSLKEYPASSWD, IS_STRING))) {
+			opt->flags |= PHP_HTTP_CURLE_OPTION_CHECK_STRLEN;
+		}
 		php_http_option_register(registry, ZEND_STRL("engine"), CURLOPT_SSLENGINE, IS_STRING);
 		php_http_option_register(registry, ZEND_STRL("version"), CURLOPT_SSLVERSION, IS_LONG);
 		if ((opt = php_http_option_register(registry, ZEND_STRL("verifypeer"), CURLOPT_SSL_VERIFYPEER, IS_BOOL))) {
@@ -1238,6 +1370,14 @@ static void php_http_curle_options_init(php_http_options_t *registry TSRMLS_DC)
 #endif
 #if PHP_HTTP_CURL_VERSION(7,19,1) && defined(PHP_HTTP_HAVE_OPENSSL)
 		php_http_option_register(registry, ZEND_STRL("certinfo"), CURLOPT_CERTINFO, IS_BOOL);
+#endif
+#if PHP_HTTP_CURL_VERSION(7,36,0)
+		if ((opt = php_http_option_register(registry, ZEND_STRL("enable_npn"), CURLOPT_SSL_ENABLE_NPN, IS_BOOL))) {
+			ZVAL_BOOL(&opt->defval, 1);
+		}
+		if ((opt = php_http_option_register(registry, ZEND_STRL("enable_alpn"), CURLOPT_SSL_ENABLE_ALPN, IS_BOOL))) {
+			ZVAL_BOOL(&opt->defval, 1);
+		}
 #endif
 	}
 }
@@ -1259,6 +1399,7 @@ static STATUS php_http_curle_set_option(php_http_option_t *opt, zval *val, void
 	php_http_client_curl_handler_t *curl = userdata;
 	CURL *ch = curl->handle;
 	zval tmp;
+	CURLcode rc = CURLE_OK;
 	STATUS rv = SUCCESS;
 	TSRMLS_FETCH_FROM_CTX(curl->client->ts);
 
@@ -1284,14 +1425,18 @@ static STATUS php_http_curle_set_option(php_http_option_t *opt, zval *val, void
 		break;
 
 	case IS_STRING:
-		if (!(opt->flags & PHP_HTTP_CURLE_OPTION_CHECK_STRLEN) || Z_STRLEN_P(val)) {
-			if (!(opt->flags & PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR) || !Z_STRVAL_P(val) || SUCCESS == php_check_open_basedir(Z_STRVAL_P(val) TSRMLS_CC)) {
-				if (opt->setter) {
-					rv = opt->setter(opt, val, curl);
-				} else if (CURLE_OK != curl_easy_setopt(ch, opt->option, Z_STRVAL_P(val))) {
-					rv = FAILURE;
-				}
+		if (opt->setter) {
+			rv = opt->setter(opt, val, curl);
+		} else if ((opt->flags & PHP_HTTP_CURLE_OPTION_CHECK_STRLEN) && !Z_STRLEN_P(val)) {
+			if (CURLE_OK != (rc = curl_easy_setopt(ch, opt->option, NULL))) {
+				rv = FAILURE;
 			}
+		} else if ((opt->flags & PHP_HTTP_CURLE_OPTION_CHECK_BASEDIR) && Z_STRVAL_P(val) && SUCCESS != php_check_open_basedir(Z_STRVAL_P(val) TSRMLS_CC)) {
+			if (CURLE_OK != (rc = curl_easy_setopt(ch, opt->option, NULL))) {
+				rv = FAILURE;
+			}
+		} else if (CURLE_OK != (rc = curl_easy_setopt(ch, opt->option, Z_STRVAL_P(val)))) {
+			rv = FAILURE;
 		}
 		break;
 
@@ -1325,7 +1470,7 @@ static STATUS php_http_curle_set_option(php_http_option_t *opt, zval *val, void
 		break;
 	}
 	if (rv != SUCCESS) {
-		php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Could not set option %s", opt->name.s);
+		php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Could not set option %s (%s)", opt->name.s, curl_easy_strerror(rc));
 	}
 	return rv;
 }
@@ -1419,9 +1564,14 @@ static php_http_client_curl_handler_t *php_http_client_curl_handler_init(php_htt
 	curl_easy_setopt(handle, CURLOPT_DEBUGFUNCTION, php_http_curle_raw_callback);
 	curl_easy_setopt(handle, CURLOPT_READFUNCTION, php_http_curle_read_callback);
 	curl_easy_setopt(handle, CURLOPT_IOCTLFUNCTION, php_http_curle_ioctl_callback);
+#if PHP_HTTP_CURL_VERSION(7,32,0)
+	curl_easy_setopt(handle, CURLOPT_XFERINFOFUNCTION, php_http_curle_xferinfo_callback);
+	curl_easy_setopt(handle, CURLOPT_XFERINFODATA, handler);
+#else
 	curl_easy_setopt(handle, CURLOPT_PROGRESSFUNCTION, php_http_curle_progress_callback);
-	curl_easy_setopt(handle, CURLOPT_DEBUGDATA, handler);
 	curl_easy_setopt(handle, CURLOPT_PROGRESSDATA, handler);
+#endif
+	curl_easy_setopt(handle, CURLOPT_DEBUGDATA, handler);
 
 	php_http_client_curl_handler_reset(handler);
 
@@ -1532,7 +1682,11 @@ static void php_http_client_curl_handler_dtor(php_http_client_curl_handler_t *ha
 	TSRMLS_FETCH_FROM_CTX(handler->client->ts);
 
 	curl_easy_setopt(handler->handle, CURLOPT_NOPROGRESS, 1L);
+#if PHP_HTTP_CURL_VERSION(7,32,0)
+	curl_easy_setopt(handler->handle, CURLOPT_XFERINFOFUNCTION, NULL);
+#else
 	curl_easy_setopt(handler->handle, CURLOPT_PROGRESSFUNCTION, NULL);
+#endif
 	curl_easy_setopt(handler->handle, CURLOPT_VERBOSE, 0L);
 	curl_easy_setopt(handler->handle, CURLOPT_DEBUGFUNCTION, NULL);
 
@@ -1582,9 +1736,16 @@ static void php_http_client_curl_dtor(php_http_client_t *h)
 
 #if PHP_HTTP_HAVE_EVENT
 	if (curl->timeout) {
+		if (event_initialized(curl->timeout) && event_pending(curl->timeout, EV_TIMEOUT, NULL)) {
+			event_del(curl->timeout);
+		}
 		efree(curl->timeout);
 		curl->timeout = NULL;
 	}
+	if (curl->evbase) {
+		event_base_free(curl->evbase);
+		curl->evbase = NULL;
+	}
 #endif
 	curl->unfinished = 0;
 
@@ -1794,7 +1955,7 @@ static STATUS php_http_client_curl_exec(php_http_client_t *h)
 	if (curl->useevents) {
 		php_http_curlm_timeout_callback(CURL_SOCKET_TIMEOUT, /*EV_READ|EV_WRITE*/0, h);
 		do {
-			int ev_rc = event_base_dispatch(PHP_HTTP_G->curl.event_base);
+			int ev_rc = event_base_dispatch(curl->evbase);
 
 #if DBG_EVENTS
 			fprintf(stderr, "%c", "X.0"[ev_rc+1]);
@@ -1838,6 +1999,9 @@ static STATUS php_http_client_curl_setopt(php_http_client_t *h, php_http_client_
 		case PHP_HTTP_CLIENT_OPT_USE_EVENTS:
 #if PHP_HTTP_HAVE_EVENT
 			if ((curl->useevents = *((zend_bool *) arg))) {
+				if (!curl->evbase) {
+					curl->evbase = event_base_new();
+				}
 				if (!curl->timeout) {
 					curl->timeout = ecalloc(1, sizeof(struct event));
 				}
@@ -2004,24 +2168,6 @@ PHP_MSHUTDOWN_FUNCTION(http_client_curl)
 	return SUCCESS;
 }
 
-#if PHP_HTTP_HAVE_EVENT
-PHP_RINIT_FUNCTION(http_client_curl)
-{
-	if (!PHP_HTTP_G->curl.event_base && !(PHP_HTTP_G->curl.event_base = event_base_new())) {
-		return FAILURE;
-	}
-	return SUCCESS;
-}
-PHP_RSHUTDOWN_FUNCTION(http_client_curl)
-{
-	if (PHP_HTTP_G->curl.event_base) {
-		event_base_free(PHP_HTTP_G->curl.event_base);
-		PHP_HTTP_G->curl.event_base = NULL;
-	}
-	return SUCCESS;
-}
-#endif /* PHP_HTTP_HAVE_EVENT */
-
 #endif /* PHP_HTTP_HAVE_CURL */
 
 /*
